﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;

public class CharacterManager : MonoBehaviour {
	[SerializeField] private float speed,jumpSpeed;
	private bool grounded=true, canDoubleJump=true;
	[SerializeField] public bool isPlatform = true;
	// Use this for initialization
	public ExplosionParams explosion;
	public float multiplier;

	public float specialMoveCounter;
	public float specialMoveTimeLimit;

	public Slider specialSlider;
	public Slider lifeSlider;

	public int lifeCount;
	public int lifeValue;

	public Camera shooterCamera;
	public Camera platformCamera;

	public Animator effectAnim;
	public Animator playerAnim;

	void Start()
	{
		specialMoveCounter = specialMoveTimeLimit;
		specialSlider.maxValue = specialMoveTimeLimit;

		lifeCount = lifeValue;
		lifeSlider.maxValue = lifeValue;
		lifeSlider.value = lifeValue;

	}

	void Update()
	{
		if(lifeCount < 0 || transform.position.y < -30f)
		{
			Death();
		}
			
		RaycastHit hit;

		if (Physics.Raycast(transform.position, transform.TransformDirection(Vector3.down), out hit, 0.6f))
		{
			if(hit.collider.gameObject.layer == 9)
			{
				grounded = true;
				canDoubleJump = true;
			}
		}

		specialMoveCounter += Time.deltaTime;
		specialSlider.value = specialMoveCounter;

		if(specialMoveCounter > specialMoveTimeLimit)
		{
			if(Input.GetMouseButton(1))
			{
				AoEExplosion();
				effectAnim.SetTrigger("Active");
				specialMoveCounter = 0;
			}
		}

		if (Input.GetButtonDown ("Jump")) {
			if (grounded) {
				Jump ();
				grounded = false;
			} else if (canDoubleJump) {
				Jump ();
				canDoubleJump = false;
			}
		}

		if (isPlatform) {
			
			if (Input.GetAxis ("Horizontal") > 0) {
				MoveCharacter ();
			}
		} else {
			MoveCharacter ();
			if (Input.GetAxis ("Horizontal") > 0) {
				SlideRightCharacter();
			}
			if (Input.GetAxis ("Horizontal") < 0) {
				SlideLeftCharacter();
			}
		}
	}

	public void Jump()
	{
		transform.GetComponent<Rigidbody> ().AddForce (transform.up * jumpSpeed);

	}

	public void MoveCharacter()
	{
		transform.Translate (Vector3.forward * speed * Time.deltaTime);
	}

	public void SlideLeftCharacter()
	{
		transform.Translate (Vector3.right * speed * Time.deltaTime);
	}

	public void SlideRightCharacter()
	{
		transform.Translate (Vector3.left * speed * Time.deltaTime);

	}

	public void OnTriggerEnter(Collider other)
	{
		if(other.gameObject.layer == 8)
		{
			lifeCount--;
			lifeSlider.value = lifeCount;
			Destroy(other.gameObject);
		}
	}

	public void SwitchToPlatform()
	{
		isPlatform = true;
		platformCamera.gameObject.SetActive(true);
		shooterCamera.gameObject.SetActive(false);
	}

	public void SwitchToShooter()
	{
		isPlatform = false;
		platformCamera.gameObject.SetActive(false);
		shooterCamera.gameObject.SetActive(true);
	}

	public void Death()
	{
		Debug.Log("Sei Morto");
	}

	public void AoEExplosion()
	{
		var rigidbodies = new List<Rigidbody>();
		var cols = Physics.OverlapSphere (transform.position, explosion.radius);
		//Add to list all attached rigidbodies on overlapspheres
		foreach (var col in cols){
			if(col.attachedRigidbody!=null && !rigidbodies.Contains (col.attachedRigidbody)){
				rigidbodies.Add (col.attachedRigidbody);
				//print ("add");
			}
		}

		//add explosion for all rigidbodies in List
		foreach(var rb in rigidbodies){
			if(rb.gameObject.layer == 8)
			{
				rb.AddExplosionForce (explosion.force, transform.position, explosion.radius, multiplier);
				Destroy(rb.gameObject,1f);
			}
		}
	}
		
}
